#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 erf
version:              2.0.0.0
visibility:           public
id:                   erf-2.0.0.0-BAjfrhskuQTIFU6BgB8zca
key:                  erf-2.0.0.0-BAjfrhskuQTIFU6BgB8zca
license:              BSD-3-Clause
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            experimental
synopsis:             The error function, erf, and related functions.
description:
    A type class for the error function, erf, and related functions.
    Instances for Float and Double.

category:             Math
abi:                  805b6a1e0175331406c0404c58f188ff
exposed:              True
exposed-modules:      Data.Number.Erf
import-dirs:          /usr/lib/ghc-8.10.5/site-local/erf-2.0.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/erf-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/erf-2.0.0.0
hs-libraries:         HSerf-2.0.0.0-BAjfrhskuQTIFU6BgB8zca
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-erf/html/erf.haddock
haddock-html:         /usr/share/doc/haskell-erf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

